<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

function clonable_echo_language_tags() {
    $tags = clonable_get_all_language_tags();

    foreach ($tags as $tag) {
        echo "<link rel=\"alternate\" hreflang=\"" . esc_attr($tag['hreflang']) . "\" href=\"". esc_url($tag['href']) . "\" />\n";
    }
}


function clonable_get_all_language_tags() {
    $tags = [];

    $json = get_option('clonable_langtag_data');
    if ($json == null) return $tags;

    $data = json_decode($json)->data;

    if (isset($data->original)) {
        $href = clonable_get_href_for_site($data->original);
        $tags[] = [
            'href' => $href,
            'hreflang' => 'x-default',
        ];

        $tags[] = [
            'href' => $href,
            'hreflang' => $data->original->langcode,
        ];
    }

    if (isset($data->clones)) {
        foreach ($data->clones as $clone) {
            $href = clonable_get_href_for_site($clone);
            $tags[] = [
                'href' => $href,
                'hreflang' => $clone->langcode,
            ];
        }
    }


    return $tags;
}

function clonable_get_href_for_site($site) {
    global $wp;

    $domain = $site->domain;
    // Use fallback '/' for original site data, since there is no notion of subfolders there
    $original_subfolder = $site->original_subfolder ?? '/';
    $clone_subfolder = $site->clone_subfolder ?? '/';

    // Swap subfolder if necessary
    $path = '/' . $wp->request;
    if (c_str_starts_with($path, $original_subfolder)) {
        $path = substr($path, strlen($original_subfolder));
        $path = $clone_subfolder . $path;
    }

    return "https://$domain$path";
}

// Compatibility functions for wordpress < 5.9.0
function c_str_starts_with( $haystack, $needle ) {
    if ( '' === $needle ) {
        return true;
    }
    return 0 === strpos( $haystack, $needle );
}

function c_str_ends_with( $haystack, $needle ) {
    if ( '' === $haystack && '' !== $needle ) {
        return false;
    }
    $len = strlen( $needle );
    return 0 === substr_compare( $haystack, $needle, -$len, $len );
}